@@ -5,4 +5,6 @@ BIN = "bin"
 EXEC_FILE = "file.exe"
 WIN32 = "win32"
 EXEC_DSC = "{0} {1}"
-EXEC_MIMETYPE = "{0} --mime-type {1}"
\ No newline at end of file
+EXEC_MIMETYPE = "{0} --mime-type {1}"
+PATH = "PATH"
+POSIX_FILE = "file"
\ No newline at end of file
